from os import getenv

import requests  # type: ignore
from aiogram import F, Router
from aiogram.types import Message

router = Router()


@router.message(F.content_type.in_({'location'}))
async def loc_handler(message: Message):
    """Срабатывает при получении точки геолокации.
    Определяет ближыйший адрес по координатам и получает погоду в текщем местоположении
    """
    api_key: str = getenv('GEO_API_KEY') or ''
    weather_key: str = getenv('WEATHER_API_KEY') or ''

    if message.location is not None:
        msg = message.location.model_dump()
    else:
        msg = {}

    lat = msg.get('latitude', 0.0)
    long = msg.get('longitude', 0.0)

    geo_rspn = requests.get(
        f'https://geocode.maps.co/reverse?lat={lat}&lon={long}&api_key={api_key}&lang=ru'
    )

    lat = round(float(lat), 2)
    long = round(float(long), 2)

    weather_rspn = requests.get(
        f'https://api.openweathermap.org/data/2.5/weather?lat={lat}&lon={long}&appid={weather_key}&units=metric&lang=ru'
    )

    await message.answer(
        text=f"Вы тут;\n{geo_rspn.json().get('display_name')}\nПогода в доме:\n{weather_rspn.json().get('main')}"
    )
